pygeodesy.ellipsoidalExact.Cartesian

Package pygeodesy :: Module ellipsoidalExact :: Class Cartesian |
[frames] | no frames]

# Class Cartesian

              object --+
                       |
            named._Named --+
                           |
            named._NamedBase --+
                               |
       vector3dBase.Vector3dBase --+
                                   |
                   vector3d.Vector3d --+
                                       |
                      object --+       |
                               |       |
                    named._Named --+   |
                                   |   |
               ecefLocals._EcefLocal --+
                                       |
             cartesianBase.CartesianBase --+
                                           |
    ellipsoidalBase.CartesianEllipsoidalBase --+
                                               |
                                              Cartesian

Extended to convert exact Cartesian to exact LatLon points.

Instance Methods
toLatLon(self, **LatLon_and_kwds) Convert this cartesian point to an exact geodetic point. |
Inherited from `ellipsoidalBase.CartesianEllipsoidalBase`: `__init__`, `convertRefFrame`, `intersections2`, `toRefFrame`, `toTransforms_` Inherited from `cartesianBase.CartesianBase`: `Roc2`, `cassini`, `collins`, `collins5`, `convertDatum`, `destinationXyz`, `hartzell`, `height3`, `height4`, `pierlot`, `pierlotx`, `tienstra`, `tienstra7`, `to2ab`, `to2ll`, `to3llh`, `toDatum`, `toEcef`, `toNvector`, `toRtp`, `toStr`, `toTransform`, `toVector` Inherited from `vector3d.Vector3d`: `bearing`, `circin6`, `circum3`, `circum4_`, `iscolinearWith`, `meeus2`, `nearestOn`, `nearestOn6`, `parse`, `radii11`, `soddy4`, `toCartesian`, `trilaterate2d2`, `trilaterate3d2` Inherited from `vector3dBase.Vector3dBase`: `__abs__`, `__add__`, `__bool__`, `__ceil__`, `__cmp__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floor__`, `__floordiv__`, `__ge__`, `__gt__`, `__hash__`, `__iadd__`, `__idiv__`, `__ifloordiv__`, `__imatmul__`, `__imod__`, `__imul__`, `__int__`, `__ipow__`, `__isub__`, `__itruediv__`, `__le__`, `__long__`, `__lt__`, `__matmul__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmatmul__`, `__rmod__`, `__rmul__`, `__round__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__sub__`, `__truediv__`, `__trunc__`, `angleTo`, `apply`, `bools`, `cmp`, `cross`, `dividedBy`, `dividedBy_`, `dot`, `equals`, `equirectangular`, `fabs`, `floats`, `floorDividedBy`, `floorDividedBy_`, `intermediateTo`, `ints`, `isconjugateTo`, `isequalTo`, `minus`, `minus_`, `negate`, `others`, `plus`, `plus_`, `pow`, `rotate`, `rotateAround`, `sum`, `times`, `times_`, `to3xyz`, `unit` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `toRepr` Inherited from `ecefLocals._EcefLocal`: `toAer`, `toEnu`, `toLocal`, `toLtp`, `toNed`, `toXyz` Inherited from `named._Named`: `__format__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `ellipsoidalBase.CartesianEllipsoidalBase`: `ellipsoidalCartesian`, `epoch`, `reframe` Inherited from `cartesianBase.CartesianBase`: `datum`, `height`, `isEllipsoidal`, `isSpherical`, `latlon`, `latlonheight`, `latlonheightdatum`, `philam`, `philamheight`, `philamheightdatum`, `sphericalCartesian` Inherited from `vector3dBase.Vector3dBase`: `crosserrors`, `euclid`, `homogeneous`, `length`, `length2`, `x`, `x2y2z2`, `x2y2z23`, `xyz`, `xyz3`, `y`, `z` Inherited from `ecefLocals._EcefLocal`: `Ecef` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toLatLon (self, **LatLon_and_kwds) |
Convert this cartesian point to an exact geodetic point. Arguments: `LatLon_and_kwds` - Optional LatLon and LatLon keyword arguments as `datum`. Use `LatLon=..., datum=...` to override this LatLon class or specify `LatLon=None`. Returns: The geodetic point (LatLon) or if `LatLon is None`, an Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with `C` and `M` if available. Raises: `TypeError` - Invalid `LatLon_and_kwds` argument. Overrides: cartesianBase.CartesianBase.toLatLon